##  Overview
GraphQL provides a high degree of flexibility, enabling you to customize queries to meet your exact requirements and retrieve specific data without over-fetching or under-fetching. When integrated with the LeanIX Reporting Library, it facilitates the creation of custom reports that are both efficient and tailored to your unique needs.
In this tutorial, you'll learn how to create a custom report using [GraphQL queries![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Finterfaces%2Flxr.ReportFacetsConfig.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://leanix.github.io/leanix-reporting/interfaces/lxr.ReportFacetsConfig.html") with the LeanIX Reporting SDK. Specifically, we'll use the [lx.executeGraphQL![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Fclasses%2Flxr.LxCustomReportLib.html%23executeGraphQL "https://leanix.github.io/leanix-reporting/classes/lxr.LxCustomReportLib.html#executeGraphQL") method, which allows you to run custom GraphQL queries directly. This report calculates the count of fact sheets and the average completion ratio for each fact sheet type defined in your workspace.
